@@ -11,11 +11,11 @@ use Module::Runtime qw/use_module/;
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
 use constant {
 	abstract   => q[compose system recipe from reclass node],
-	usage_desc => q[%c install %o NODE [SUITE]],
+	usage_desc => q[%c install %o NODE [NODE...]],
 };
 
 sub description
@@ -40,9 +40,11 @@ sub command_names
 sub opt_spec
 {
 	return (
-		[   "datadir=s",
-			"directory containing profiles and skeletons (current)"
-		],
+		[ "suite=s",    "suite of classes to use (wheezy)" ],
+		[ "nodedir=s",  "location of nodes (current dir)" ],
+		[ "classdir=s", "location of classes (XDG_DATA_DIRS/suite)" ],
+		[ "datadir=s",  "location with nodes and classes/suite below" ],
+		[ "skeldir=s",  "location of skeleton files (use builtin)" ],
 		[ "format=s", "serialize recipe(s) in this format (preseed script)" ],
 		[ "verbose|v", "verbose output" ],
 	);
@@ -52,19 +54,20 @@ sub execute
 {
 	my $self = shift;
 	my ( $opt, $args ) = @_;
-	my $datadir = $opt->{datadir};
-	my $node    = shift @$args;
-	my $suite   = shift @$args;
 
 	my $data = use_module('Boxer::Task::Classify')->new(
-		datadir => $datadir,
-		suite   => $suite,
-	)->run;
-	use_module('Boxer::Task::Serialize')->new(
-		data    => $data,
-		datadir => $datadir,
-		node    => $node,
+		suite    => $opt->{suite},
+		nodedir  => $opt->{nodedir},
+		classdir => $opt->{classdir},
+		datadir  => $opt->{datadir},
 	)->run;
+	for my $node (@$args) {
+		use_module('Boxer::Task::Serialize')->new(
+			skeldir => $opt->{skeldir},
+			data    => $data,
+			node    => $node,
+		)->run;
+	}
 }
 
 1;
