@@ -1,34 +1,39 @@
 package Boxer::Task::Classify;
 
 use 5.010;
-use autodie;
 use strictures 1;
 use utf8;
 use autodie qw(:all);
+use IPC::System::Simple;
 
 use Moo;
 use Types::Standard qw( Str Undef );
 use Types::Path::Tiny qw( Dir );
 extends 'Boxer::Task';
 
+use File::BaseDir qw(data_dirs);
 use Capture::Tiny qw(capture_stdout);
 use YAML::XS;
 
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = '0.002';
+our $VERSION   = '0.003';
 
-my $workdir = Dir->plus_coercions(
-	Str,   q{ 'Path::Tiny'->new($_) },
-	Undef, q{ 'Path::Tiny'->cwd },
-);
+# permit callers to sloppily pass undefined values
+sub BUILDARGS
+{
+	my ( $class, %args ) = @_;
+	delete @args{ grep !defined( $args{$_} ), keys %args };
+	return {%args};
+}
 
 has datadir => (
-	is       => 'ro',
-	isa      => $workdir,
-	coerce   => $workdir->coercion,
+	is       => 'lazy',
+	isa      => Dir,
+	coerce   => Dir->coercion,
 	required => 1,
+	default  => sub { scalar( data_dirs( 'boxer', $_[0]->suite ) ) },
 );
 
 has suite => (
@@ -38,12 +43,20 @@ has suite => (
 	default  => sub {'wheezy'},
 );
 
-has profiledir => (
+has classdir => (
 	is       => 'lazy',
 	isa      => Dir,
 	coerce   => Dir->coercion,
 	required => 1,
-	default  => sub { $_[0]->datadir->child( 'profiles', $_[0]->suite ) },
+	default  => sub { $_[0]->datadir->child('classes') },
+);
+
+has nodedir => (
+	is       => 'lazy',
+	isa      => Dir,
+	coerce   => Dir->coercion,
+	required => 1,
+	default  => sub { $_[0]->datadir ? $_[0]->datadir->child('nodes') : '.' },
 );
 
 sub run
@@ -56,7 +69,11 @@ sub run
 				system(
 					'reclass',
 					'-b',
-					$self->profiledir,
+					'',
+					'-c',
+					$self->classdir,
+					'-u',
+					$self->nodedir,
 					'--inventory',
 				);
 			}
